@@ -3,22 +3,22 @@
 #' Converts long country names into one of many different coding schemes.
 #' Translates from one scheme to another. Converts country name or coding
 #' scheme to the official short English country name. Creates a new variable
-#' with the name of the continent or region to which each country belongs. 
+#' with the name of the continent or region to which each country belongs.
 #'
 #' @param sourcevar Vector which contains the codes or country names to be converted
 #' @param origin Coding scheme of origin (name enclosed in quotes "")
 #' @param destination Coding scheme of destination (name enclosed in quotes "")
 #' @param warn Prints unique elements from sourcevar for which no match was found
-#' @keywords countrycode 
-#' @note Supports the following coding schemes: Correlates of War character, 
-#'   CoW-numeric, ISO3-character, ISO3-numeric, ISO2-character, IMF numeric, FIPS 10-4,
-#'   FAO numeric, United Nations numeric, World Bank character, 
-#'   official English short country names (ISO), continent, region. 
-#' 
+#' @keywords countrycode
+#' @note Supports the following coding schemes: Correlates of War character,
+#'   CoW-numeric, ISO3-character, ISO3-numeric, ISO2-character, IMF numeric, International
+#'   Olympic Committee, FIPS 10-4, FAO numeric, United Nations numeric,
+#'   World Bank character, official English short country names (ISO), continent, region.
+#'
 #'   The following strings can be used as arguments for \code{origin} or
 #'   \code{destination}: "cowc", "cown", "iso3c", "iso3n", "iso2c", "imf",
-#'   "fips104", "fao", "un", "wb", "country.name".  The following strings can be
-#'   used as arguments for \code{destination} \emph{only}:  "continent", "region" 
+#'   "fips104", "fao", "ioc", "un", "wb", "country.name".  The following strings can be
+#'   used as arguments for \code{destination} \emph{only}:  "continent", "region"
 #' @export
 #' @aliases countrycode
 #' @examples
@@ -26,9 +26,8 @@
 #' countrycode(codes.of.origin, "cowc", "iso3c")
 countrycode <- function (sourcevar, origin, destination, warn=FALSE){
     # Sanity check
-    origin_codes<-c("cowc", "cown", "fips04", "imf", "iso2c", "iso3c", "iso3n", "fao", "un", "wb", "country.name")
-    destination_codes<-c("region", "continent", "cowc", "cown", "fao", "fips04", "imf", 
-                "iso2c", "iso3c", "iso3n", "un", "wb", "country.name")
+    origin_codes <- names(countrycode_data)[!(names(countrycode_data) %in% c("continent","region","regex"))]
+    destination_codes <- names(countrycode_data)[!(names(countrycode_data) %in% c("regex"))]
     if (!origin %in% origin_codes){stop("Origin code not supported")}
     if (!destination %in% destination_codes){stop("Destination code not supported")}
     if (origin == 'country.name'){
@@ -74,9 +73,9 @@ countrycode <- function (sourcevar, origin, destination, warn=FALSE){
 #'
 #' Runs a series of tests.
 #' Returns TRUE if all tests passed.
-#' Prints test description when some tests fail. 
+#' Prints test description when some tests fail.
 #'
-#' @keywords countrycode_test 
+#' @keywords countrycode_test
 #' @aliases countrycode_test
 countrycode_test <- function(){
     print("Don't worry about warning messages produced by this function. What matters is the TRUE outcome")
@@ -88,8 +87,8 @@ countrycode_test <- function(){
        warning('Missing values test failed')
     }
     # Congo
-    congos = c('republic of congo', 'republic of the congo', 'congo, republic of the', 'congo, republic', 
-               'democratic republic of the congo', 'congo, democratic republic of the', 'dem rep of the congo', 
+    congos = c('republic of congo', 'republic of the congo', 'congo, republic of the', 'congo, republic',
+               'democratic republic of the congo', 'congo, democratic republic of the', 'dem rep of the congo',
                'the democratic republic of congo')
     x = countrycode(congos, 'country.name', 'iso3c')
     if(!all(x == c(rep('COG',4), rep('COD',4)))){
@@ -112,7 +111,7 @@ countrycode_test <- function(){
         warning('nomatch test failed')
     }
     # Multiple regex matches
-    x = countrycode(countrycode_data[,'country.name'], 'country.name', 'cowc', warn=TRUE)  
+    x = countrycode(countrycode_data[,'country.name'], 'country.name', 'cowc', warn=TRUE)
     return(test_result)
 }
 
